@@ -30,12 +30,12 @@ and docbook-xsl in your Build-Depends control field.
   <!ENTITY dhfirstname "<firstname>FIRSTNAME</firstname>">
   <!ENTITY dhsurname   "<surname>SURNAME</surname>">
   <!-- Please adjust the date whenever revising the manpage. -->
-  <!ENTITY dhdate      "<date>February  7, 2010</date>">
+  <!ENTITY dhdate      "<date>February 13, 2010</date>">
   <!-- SECTION should be 1-8, maybe w/ subsection other parameters are
        allowed: see man(7), man(1). -->
   <!ENTITY dhsection   "<manvolnum>SECTION</manvolnum>">
-  <!ENTITY dhemail     "<email>trowerm@gmail.com</email>">
-  <!ENTITY dhusername  "Matt Trower">
+  <!ENTITY dhemail     "<email>mtrower2@illinois.edu</email>">
+  <!ENTITY dhusername  "unknown">
   <!ENTITY dhucpackage "<refentrytitle>THRIFTYDRINKER</refentrytitle>">
   <!ENTITY dhpackage   "thriftydrinker">
 
